from distutils.core import setup
setup(
  name = 'itunes_podcast_rss',
  packages = ['itunes_podcast_rss'],
  version = '1.0',
  description = 'Python library to obtain RSS feed URL from iTunes link',
  author = 'Michal Holub',
  author_email = 'holub.michal@gmail.com',
  url = 'https://github.com/wotaen/itunes_podcast_rss',
  download_url = 'https://codeload.github.com/wotaen/itunes_podcast_rss/legacy.tar.gz/1.0',
  keywords = ['itunes', 'podcast', 'rss'],
  classifiers = [],
)
